#!/bin/bash
# shellcheck disable=SC1091 # Cannot resolve paths in variables

PROJECT_HOME="$(realpath -s --relative-to . "$(dirname "$0")/..")" || exit
. "$PROJECT_HOME/scripts/util.sh" || exit

# Confirm that Hostname in ssh_config has changed from initial value
grep -qx "    Hostname x.x.x.x" "$PROJECT_HOME"/config/ssh_config &&
	error $"Hostname in config/ssh_config has not been changed; set the IP address of Armadillo."

confirm_crlf "$PROJECT_HOME"/app

get_project_name
get_project_type

case "$PROJECT_TYPE" in
"shell"|"python")
	COPY_APP_DIR="${PROJECT_HOME}/app"
	;;&
"c")
	# exec make command.
	build_project
	COPY_APP_DIR="${PROJECT_HOME}/swu/dest"
	;;&
"flutter")
	COPY_APP_DIR="$PROJECT_HOME/app/build/elinux/arm64/release/bundle"
	;;&
"gateway")
	# gateway project is not copied because the container config does not exist
	DEST_DIR="/var/app/rollback/volumes/gw_container"
	copy_run "${PROJECT_HOME}/app/src" "${DEST_DIR}/src/customize"
	copy_run "${PROJECT_HOME}/app/config/sensing_mgr.conf" "${DEST_DIR}/config/"
	copy_run "${PROJECT_HOME}/app/config/cloud_agent.conf" "${DEST_DIR}/config/" \
		"a6e-gw-container"
	;;
*)
	# Copy container config file
	CONTAINERS_DIR="$PROJECT_HOME/swu/app/etc/atmark/containers"
	CONTAINER_CONFIG_FILE="$CONTAINERS_DIR/$PROJECT.conf"
	mkdir -p "$CONTAINERS_DIR"
	sed -e "s/{{PROJECT}}/$PROJECT/g" "$PROJECT_HOME/config/app.conf" >"$CONTAINER_CONFIG_FILE"

	copy_run "$CONTAINER_CONFIG_FILE" "/etc/atmark/containers/$PROJECT.conf"
	copy_run "$COPY_APP_DIR" \
		"/var/app/rollback/volumes/${PROJECT}" \
		"$PROJECT"
	;;
esac

